@@ -30,22 +30,16 @@ def create_grpc_server(descriptor: FileDescriptor):
   return server
 
 
-def _signal_handler(*_) -> None:
-  shutdown_event.set()
-
-
 async def start_server(server: Server, gateway: bool = True):
   logging.info('starting grpc server...')
   await server.start()
   logging.info('started grpc server on port 8080')
+  loop = asyncio.get_event_loop()
   try:
     if gateway:
-      loop = asyncio.get_event_loop()
-      loop.add_signal_handler(signal.SIGTERM, _signal_handler)
-      await start_gateway(server.__dict__['descriptor'], shutdown_trigger=shutdown_event.wait)
-      loop.create_task(start_server(server))
-      loop.run_forever()
-    else:
-      await server.wait_for_termination()
+      gateway = start_gateway(server.__dict__['descriptor'])
+      loop.create_task(gateway)
+    loop.create_task(server.wait_for_termination())
+    loop.wait_for_termination()
   except KeyboardInterrupt:
     logging.info('stopped server (keyboard interrupt)')
